@@ -23,6 +23,7 @@
 #' @param prefix Prefix string for keys in BibTeX entries; by default, it is
 #'   \samp{R-} unless \code{\link{option}('knitr.bib.prefix')} has been set to
 #'   another string.
+#' @param lib.loc A vector of path names of R libraries.
 #' @return A list containing the citations. Citations are also written to the
 #'   \code{file} as a side effect.
 #' @note Some packages on CRAN do not have standard bib entries, which was once
@@ -57,8 +58,10 @@
 #' str(knitr:::.tweak.bib)
 write_bib = function(
   x = .packages(), file = '', tweak = TRUE, width = NULL,
-  prefix = getOption('knitr.bib.prefix', 'R-')
+  prefix = getOption('knitr.bib.prefix', 'R-'), lib.loc = NULL
 ) {
+  system.file = function(...) base::system.file(..., lib.loc = lib.loc)
+  citation = function(...) utils::citation(..., lib.loc = lib.loc)
   idx = mapply(system.file, package = x) == ''
   if (any(idx)) {
     warning('package(s) ', paste(x[idx], collapse = ', '), ' not found')
@@ -67,7 +70,16 @@ write_bib = function(
   x = setdiff(x, .base.pkgs) # remove base packages
   x = sort(x)
   bib = sapply(x, function(pkg) {
-    cite = citation(pkg, auto = if (pkg == 'base') NULL else TRUE)
+    cite = citation(pkg, auto = if (pkg != 'base') {
+      meta = packageDescription(pkg, lib.loc = lib.loc)
+      # don't use the CRAN URL if the package has provided its own URL
+      if (identical(meta$Repository, 'CRAN') && !is.null(meta$URL)) {
+        # however, the package may have provided multiple URLs, in which case we
+        # still use the CRAN URL
+        if (!grepl('[, ]', meta$URL)) meta$Repository = NULL
+      }
+      meta
+    })
     if (tweak) {
       # e.g. gpairs has "gpairs: " in the title
       cite$title = gsub(sprintf('^(%s: )(\\1)', pkg), '\\1', cite$title)
@@ -86,8 +98,10 @@ write_bib = function(
     bib = lapply(bib, function(b) {
       b['author'] = sub('Duncan Temple Lang', 'Duncan {Temple Lang}', b['author'])
       # remove the ugly single quotes required by CRAN policy
-      b['title'] = gsub(
-        "'(RStudio|Htmlwidgets|iframes|TeX Live|LaTeX)'", '\\1', b['title']
+      b['title'] = gsub("(^|\\W)'([^']+)'(\\W|$)", '\\1\\2\\3', b['title'])
+      # keep the first URL if multiple are provided
+      if (!is.na(b['note'])) b['note'] = gsub(
+        '(^.*?https?://.*?),\\s+https?://.*?(},\\s*)$', '\\1\\2', b['note']
       )
       if (!('year' %in% names(b))) b['year'] = .this.year
       b
@@ -128,10 +142,12 @@ write_bib = function(
 #' @include utils.R
 
 # hack non-standard author fields
-.tweak.bib = local(if (Sys.info()[['sysname']] == 'Darwin') {
+.tweak.bib = local({
   x = read.csv(inst_dir('misc/tweak_bib.csv'), stringsAsFactors = FALSE)
-  x = x[order(xtfrm(x$package)), , drop = FALSE]  # reorder entries by package names
-  try_silent(write.csv(x, inst_dir('misc/tweak_bib.csv'), row.names = FALSE))
+  if (Sys.getlocale('LC_COLLATE') == 'en_US.UTF-8') {
+    x = x[order(xtfrm(x$package)), , drop = FALSE]  # reorder entries by package names
+    try_silent(write.csv(x, inst_dir('misc/tweak_bib.csv'), row.names = FALSE))
+  }
   setNames(
     lapply(x$author, function(a) c(author = sprintf('  author = {%s},', a))),
     x$package
