@@ -15,9 +15,13 @@ hook_plot_md = function(x, options) {
     }
     if (office_output) {
       if (options$fig.align != 'default') {
-        warning('Chunk options fig.align is not supported for ', to, ' output')
+        warn_options_unsupported('fig.align', to)
         options$fig.align = 'default'
       }
+      if (!is.null(options$fig.alt)) {
+        warn_options_unsupported('fig.alt', to)
+        options$fig.alt = NULL
+      }
       return(hook_plot_md_pandoc(x, options))
     }
   }
@@ -29,8 +33,8 @@ hook_plot_md = function(x, options) {
 need_special_plot_hook = function(options) {
   opts = opts_chunk$get(default = TRUE)
   for (i in c(
-    'out.width', 'out.height', 'out.extra',
-    'fig.align', 'fig.subcap', 'fig.env', 'fig.scap'
+    'out.width', 'out.height', 'out.extra', 'fig.align', 'fig.subcap',
+    'fig.env', 'fig.scap', 'fig.alt'
   )) if (!identical(options[[i]], opts[[i]])) return(TRUE)
   FALSE
 }
@@ -51,7 +55,8 @@ hook_plot_md_base = function(x, options) {
   plot1 = ai || options$fig.cur <= 1L
   plot2 = ai || options$fig.cur == options$fig.num
   to = pandoc_to(); from = pandoc_from()
-  if (is.null(w) && is.null(h) && is.null(s) && a == 'default' && !(pandoc_html && in_bookdown)) {
+  if (is.null(w) && is.null(h) && is.null(s) && is.null(options$fig.alt) &&
+      a == 'default' && !(pandoc_html && in_bookdown)) {
     # append <!-- --> to ![]() to prevent the figure environment in these cases
     nocap = cap == '' && !is.null(to) && !grepl('^markdown', to) &&
       (options$fig.num == 1 || ai) && !grepl('-implicit_figures', from)
@@ -192,7 +197,8 @@ hooks_markdown = function(strict = FALSE, fence_char = '`') {
       x = gsub('[\n]+$', '', x)
       x = gsub('^[\n]+', '\n', x)
       if (isTRUE(options$collapse)) {
-        x = gsub(paste0('\n([', fence_char, ']{3,})\n+\\1(', tolower(options$engine), ')?\n'), "\n", x)
+        r = sprintf('\n([%s]{3,})\n+\\1((\\{[.])?%s[^\n]*)?\n', fence_char, tolower(options$engine))
+        x = gsub(r, '\n', x)
       }
       if (is.null(s <- options$indent)) return(x)
       line_prompt(x, prompt = s, continue = s)
