@@ -167,6 +167,16 @@ is_lyx = function() {
   grepl('[.]Rnw$', args[1]) && !is.na(Sys.getenv('LyXDir', NA))
 }
 
+# detect if running on CRAN (assuming that CRAN does not set CI or NOT_CRAN=true)
+is_cran = function() {
+  tolower(Sys.getenv('R_CRANDALF')) == 'true' ||
+    !any(tolower(Sys.getenv(c('CI', 'NOT_CRAN'))) == 'true')
+}
+
+is_cran_check = function() {
+  is_cran() && is_R_CMD_check()
+}
+
 # round a number to getOption('digits') decimal places by default, and format()
 # it using significant digits if the option knitr.digits.signif = TRUE
 round_digits = function(x) {
@@ -1041,35 +1051,3 @@ make_unique = function(x) {
 #' browseURL('logo.html') # you can check its HTML source
 #' }
 image_uri = function(f) xfun::base64_uri(f)
-
-# TODO: remove this function after bookdown > 0.21 is on CRAN
-is_abs_path = function(...) xfun::is_abs_path(...)
-
-# check if DESCRIPTION has dependencies on certain packages
-desc_has_dep = function(pkg, dir = '.') {
-  res = rep(NA, length(pkg))
-  if (!file.exists(f <- file.path(dir, 'DESCRIPTION'))) return(res)
-  info = read.dcf(f, fields = c('Package', 'Depends', 'Imports', 'Suggests'))
-  if (nrow(info) < 1 || is.na(info[1, 'Package'])) return(res)
-  pkg %in% unlist(strsplit(info, '[[:space:],]+'))
-}
-
-# return TRUE if DESCRIPTION doesn't exist or pkg has been declared as dependency
-test_desc_dep = function(pkg, dir = '.') {
-  res = desc_has_dep(pkg, dir)
-  all(is.na(res)) || (all(res) && has_packages(pkg))
-}
-
-# TODO: remove this hack in the future when no CRAN/BioC packages have the issue
-test_vig_dep = function(pkg) {
-  if (skip_cran_bioc() || test_desc_dep(pkg, '..')) return()
-  p = read.dcf(file.path('..', 'DESCRIPTION'), fields = 'Package')[1, 1]
-  stop2(
-    "The '", pkg, "' package should be installed and declared as a dependency of the '", p,
-    "' package (e.g., in the 'Suggests' field of DESCRIPTION), because the ",
-    "latter contains vignette(s) built with the '", pkg, "' package. Please see ",
-    "https://github.com/yihui/knitr/issues/1864 for more information."
-  )
-}
-
-skip_cran_bioc = function() is_R_CMD_check() || Sys.getenv('BBS_HOME') != ''
